@@ -22,7 +22,7 @@ http://www.gnu.org/copyleft/gpl.html for license.
 See my vids at http://amv.reimeika.ca !
 """
 
-version = '0.0.7'
+version = '0.0.10'
 convert = 'convert'
 mencoder = 'mencoder'
 lameenc = 'lame'
@@ -362,7 +362,7 @@ def do_encode():
         meinfo = '-quiet'
         hinfo = ''
 
-    common_vopts = meinfo + ' -mf type=%s:fps=%s ' % (ext[1:], fps) + \
+    common_vopts = meinfo + ' -mf type=%s:fps=%s -mc 0 -noskip ' % (ext[1:], fps) + \
                   '-vf hqdn3d=2:1:3,pp=va:128:8/ha:128:8/dr,dsize=%s' % aspect
 
     if vtype[-1] == 's':
@@ -372,7 +372,7 @@ def do_encode():
         cpass = ''
     elif vtype[-1] == 'h':
         codec_vopts = '-ovc x264 -x264encopts ' + \
-                      'frameref=15:deblockalpha=3:4x4mv:subq=5' + hinfo + \
+                      'frameref=15:subq=5' + hinfo + \
                       ':bitrate='
         cpass = 'pass='
     else:
@@ -456,12 +456,12 @@ def do_encode():
     if not quiet: print 'Encoding and multiplexing...'
     if vtype[-1] == 's':
         command = """cd %(source_dir)s ; \\
-%(mencoder)s %(aviopts)s %(avimp3)s "mf://%(syml)s%(img_pre)s*%(ext)s" %(mencoder_opts)s -o %(vidname)s %(std)s""" % all_vars
+%(mencoder)s %(aviopts)s %(avimp3)s "mf://%(syml)s%(img_pre)s*%(ext)s" %(mencoder_opts)s -o "%(vidname)s" %(std)s""" % all_vars
         run(command)
     else:
         command = """cd %(source_dir)s ; \\
 %(mencoder)s %(aviopts)s -nosound "mf://%(syml)s%(img_pre)s*%(ext)s" %(mencoder_opts)s1 -o /dev/null %(std)s ; \\
-%(mencoder)s %(aviopts)s %(avimp3)s "mf://%(syml)s%(img_pre)s*%(ext)s" %(mencoder_opts)s2 -o %(vidname)s %(std)s
+%(mencoder)s %(aviopts)s %(avimp3)s "mf://%(syml)s%(img_pre)s*%(ext)s" %(mencoder_opts)s2 -o "%(vidname)s" %(std)s
 """ % all_vars
         run(command)
 
@@ -595,8 +595,14 @@ if __name__ == '__main__':
          print 'Improper image name prefix.'
          raise SystemExit
 
+    temp_dir = ''
     img_dir = opts.get('-d', '.')
     img_dir = os.path.abspath(img_dir)
+    if ' ' in img_dir:
+        temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(img_dir, temp_dir + '/img_dir')
+        img_dir = temp_dir + '/img_dir'
+
     if not os.path.isdir(img_dir):
         print 'The image source directory: '  + img_dir + \
               ' does not exist!'
@@ -741,9 +747,14 @@ if __name__ == '__main__':
             print 'Could not create the work directory ' + \
                   work_dir
             raise SystemExit
+    if ' ' in work_dir:
+        if temp_dir == '':
+            temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(work_dir, temp_dir + '/work_dir')
+        work_dir = temp_dir + '/work_dir'
 
     sndf = opts.get('-s', os.path.join(img_dir, 'audio'))
-    sndf = os.path.abspath(sndf)
+#    sndf = os.path.abspath(sndf)
     rawsndf = True
     if not os.path.isfile(sndf):
         audio = False
@@ -780,6 +791,8 @@ if __name__ == '__main__':
     do_encode()
     if not keep:
         do_clean()
+    if temp_dir != '':
+        shutil.rmtree(temp_dir)
     if not quiet: print "Done!"
 
 
@@ -799,4 +812,7 @@ CHANGELOG:
                       Fixed snow encoding (still highly experimental).
                       Fixed bitrate levels.
 13 Mar 2006 : 0.0.7 : tweaked bitrate levels.
+28 Jun 2007 : 0.0.8 : handles paths with spaces appropriately
+                      (thanks Gabriel).
+08 Dec 2007 : 0.0.9 : added "-mc 0" and "-noskip" options.
 """
