@@ -25,7 +25,7 @@ http://www.gnu.org/copyleft/gpl.html for license.
 See my vids at http://amv.reimeika.ca !
 """
 
-version = '0.0.5'
+version = '0.0.6'
 convert = 'convert'
 
 usage = \
@@ -465,8 +465,14 @@ if __name__ == '__main__':
          print 'Improper image name prefix.'
          raise SystemExit
 
+    temp_dir = ''
     img_dir = opts.get('-d', '.')
     img_dir = os.path.abspath(img_dir)
+    if ' ' in img_dir:
+        temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(img_dir, temp_dir + '/img_dir')
+        img_dir = temp_dir + '/img_dir'
+
     if not os.path.isdir(img_dir):
         print 'The image source directory: '  + img_dir + \
               ' does not exist!'
@@ -598,6 +604,11 @@ if __name__ == '__main__':
             print 'Could not create the work directory ' + \
                   work_dir
             raise SystemExit
+    if ' ' in work_dir:
+        if temp_dir == '':
+            temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(work_dir, temp_dir + '/work_dir')
+        work_dir = temp_dir + '/work_dir'
 
     # Audio is not used
     sndf = opts.get('-s', os.path.join(img_dir, 'audio'))
@@ -616,6 +627,8 @@ if __name__ == '__main__':
     do_encode()
     if not keep:
         do_clean()
+    if temp_dir != '':
+        shutil.rmtree(temp_dir)
     if not quiet: print "Done!"
 
 
@@ -630,4 +643,6 @@ CHANGELOG:
 21 Mar 2005 : 0.0.4 : use env python (hopefully >= 2.3)
 09 Mar 2006 : 0.0.5 : added '-depth 8' to resize, as ImageMagick
                       keeps changing its damn behaviour.
+28 Jun 2007 : 0.0.6 : handles paths with spaces appropriately
+                      (thanks Gabriel).
 """
