@@ -36,7 +36,7 @@ mpeg_encoder.py -h
 mpeg_encoder.py -V
 mpeg_encoder.py -C
 mpeg_encoder.py [-o out] [-p pre] [-d dir] [-a aspect] [-D delay]
-                [-q|-v] [-t type] [-k] [-m] [-e [[-w dir] [-c geom] [-r geom]]]
+                [-q|-v] [-t type] [-k] [-e [[-w dir] [-c geom] [-r geom]]]
                 [-s sndfile] [-b sndrate] [-f fpscode] [-L lv1file]
                 [firstframe lastframe]
       """
@@ -188,8 +188,6 @@ OPTIONS:
             the sound will always be stereo and sampled at 44100Hz.
             Default: "audio" inside "dir" as specified by "-d".
 
--m          Force mono audio.
-
 -b sndrate  sample rate of the sound file in Hertz.
             Default: "44100".
 
@@ -419,36 +417,24 @@ def do_encode():
     if vtype == 'hi':
         mpeg2enc_opts = common_opts + \
                         '-a %s -b 13000 -q 4 -B 600 -V 2000' % aspect
-        if mono == ' -m':
-            mp2enc_opts = '-b 192 -r 44100'
-        else:
-            mp2enc_opts = '-b 384 -r 44100'
+        mp2enc_opts = '-b 384 -r 44100'
         mplex_opts = '-f 0 -b 2200 -V -r 14000'
     elif vtype == 'mh':
         mpeg2enc_opts = common_opts + \
                         '-a %s -b 6500 -q 4 -B 350 -V 1000' % aspect
-        if mono == ' -m':
-            mp2enc_opts = '-b 128 -r 44100'
-        else:
-            mp2enc_opts = '-b 256 -r 44100'
+        mp2enc_opts = '-b 256 -r 44100'
         mplex_opts = '-f 0 -b 1100 -V -r 7000'
     elif vtype == 'ml':
         denoise = '1'
         mpeg2enc_opts = common_opts + \
                         '-a %s -b 6500 -q 4 -B 300 -V 1000' % aspect
-        if mono == ' -m':
-            mp2enc_opts = '-b 192 -r 44100'
-        else:
-            mp2enc_opts = '-b 96 -r 44100'
+        mp2enc_opts = '-b 192 -r 44100'
         mplex_opts = '-f 0 -b 1100 -V -r 7000'
     elif vtype in ['lo', 'qlo']:
         denoise = '1'
         mpeg2enc_opts = common_opts + \
                         '-a %s -b 2500 -q 6 -B 160 -V 1000' % aspect
-        if mono == ' -m':
-            mp2enc_opts = '-b 64 -r 44100'
-        else:
-            mp2enc_opts = '-b 128 -r 44100'
+        mp2enc_opts = '-b 128 -r 44100'
         mplex_opts = '-f 0 -b 1100 -V -r 3000'
     elif vtype in ['vcd', 'pvcd']:
         scaler = yuvscaler + ' %s -O VCD %s |' % (widescreen, std)
@@ -471,8 +457,6 @@ def do_encode():
         pcmsox_opts = '-r 48000 -x -t raw'
         mplex_opts = '-f 8 -L 48000:2:16'
 
-    mp2enc_opts = mp2enc_opts + mono
-
     if img_dir != work_dir and not enhance:
         source_dir = img_dir
     else:
@@ -546,7 +530,7 @@ def do_encode():
 
         if not quiet: print 'Multiplexing...'
         command = """
-%(mplex)s %(mplex_opts)s -O %(delaysh)sms %(tmpsndf)s %(mpegv)s -o %(vidname)s""" % all_vars
+%(mplex)s %(mplex_opts)s -O %(delaysh)sms %(tmpsndf)s %(mpegv)s -o "%(vidname)s" """ % all_vars
         run(command)
 
         if rawsndf and os.path.exists(wav): os.remove(wav)
@@ -554,7 +538,7 @@ def do_encode():
     else:
         if not quiet: print 'Multiplexing...'
         command = """
-%(mplex)s %(mplex_opts)s %(mpegv)s -o %(vidname)s""" % all_vars
+%(mplex)s %(mplex_opts)s %(mpegv)s -o "%(vidname)s" """ % all_vars
         run(command)
         
     if os.path.exists(mpegv): os.remove(mpegv)
@@ -637,7 +621,7 @@ if __name__ == '__main__':
 
     try:
         (opts, args) = getopt.getopt(sys.argv[1:], \
-                                         'ho:p:d:w:a:qvt:emkc:r:s:b:f:VCD:L:')
+                                         'ho:p:d:w:a:qvt:ekc:r:s:b:f:VCD:L:')
     except:
         print "Something's wrong. Try the '-h' flag."
         raise SystemExit
@@ -678,8 +662,14 @@ if __name__ == '__main__':
          print 'Improper image name prefix.'
          raise SystemExit
 
+    temp_dir = ''
     img_dir = opts.get('-d', '.')
     img_dir = os.path.abspath(img_dir)
+    if ' ' in img_dir:
+        temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(img_dir, temp_dir + '/img_dir')
+        img_dir = temp_dir + '/img_dir'
+
     if not os.path.isdir(img_dir):
         print 'The image source directory: '  + img_dir + \
               ' does not exist!'
@@ -708,11 +698,6 @@ if __name__ == '__main__':
     last_frame_num = last_frame_num.zfill(8)
     last_num = int(last_frame_num)
 
-    if '-m' in opts:
-        mono = ' -m'
-    else:
-        mono = ''
-        
     aspect = opts.get('-a', '2')
 
     if aspect not in [str(i) for i in xrange(1,5)]:
@@ -818,9 +803,14 @@ if __name__ == '__main__':
             print 'Could not create the work directory ' + \
                   work_dir
             raise SystemExit
+    if ' ' in work_dir:
+        if temp_dir == '':
+            temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(work_dir, temp_dir + '/work_dir')
+        work_dir = temp_dir + '/work_dir'
 
     sndf = opts.get('-s', os.path.join(img_dir, 'audio'))
-    sndf = os.path.abspath(sndf)
+#    sndf = os.path.abspath(sndf)
     rawsndf = True
     if not os.path.isfile(sndf):
         audio = False
@@ -850,6 +840,8 @@ if __name__ == '__main__':
     do_encode()
     if not keep:
         do_clean()
+    if temp_dir != '':
+        shutil.rmtree(temp_dir)
     if not quiet: print "Done!"
 
 
@@ -886,5 +878,6 @@ CHANGELOG:
 26 Aug 2005 : 0.1.6 : Bypass 2.21:1 brokenness.
 09 Mar 2006 : 0.1.7 : added '-depth 8' to resize, as ImageMagick
                       keeps changing its damn behaviour.
-22 Aug 2006 : 0.1.8 : add support for mono audio (Salsaman)
+28 Jun 2007 : 0.1.8 : handles paths with spaces appropriately
+                      (thanks Gabriel).
 """
