@@ -19,7 +19,7 @@ http://www.gnu.org/copyleft/gpl.html for license.
 See my vids at http://amv.reimeika.ca !
 """
 
-version = '0.1.4'
+version = '0.1.5'
 convert = 'convert'
 mencoder = 'mencoder'
 oggenc = 'oggenc'
@@ -447,7 +447,7 @@ def do_encode():
 
         if not quiet: print 'Multiplexing...'
         command = """
-%(ogmplex)s -o %(vidname)s %(mpegv)s -s 0%(delaysh)s %(ogg)s %(std)s""" % all_vars
+%(ogmplex)s -o "%(vidname)s" %(mpegv)s -s 0%(delaysh)s %(ogg)s %(std)s""" % all_vars
         run(command)
 
         if rawsndf and os.path.exists(wav): os.remove(wav)
@@ -455,7 +455,7 @@ def do_encode():
     else:
         if not quiet: print 'Multiplexing...'
         command = """
-%(ogmplex)s -o %(vidname)s %(mpegv)s %(std)s""" % all_vars
+%(ogmplex)s -o "%(vidname)s" %(mpegv)s %(std)s""" % all_vars
         run(command)
 
     if os.path.exists(mpegv): os.remove(mpegv)
@@ -583,8 +583,14 @@ if __name__ == '__main__':
          print 'Improper image name prefix.'
          raise SystemExit
 
+    temp_dir = ''
     img_dir = opts.get('-d', '.')
     img_dir = os.path.abspath(img_dir)
+    if ' ' in img_dir:
+        temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(img_dir, temp_dir + '/img_dir')
+        img_dir = temp_dir + '/img_dir'
+
     if not os.path.isdir(img_dir):
         print 'The image source directory: '  + img_dir + \
               ' does not exist!'
@@ -728,9 +734,14 @@ if __name__ == '__main__':
             print 'Could not create the work directory ' + \
                   work_dir
             raise SystemExit
+    if ' ' in work_dir:
+        if temp_dir == '':
+            temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(work_dir, temp_dir + '/work_dir')
+        work_dir = temp_dir + '/work_dir'
 
     sndf = opts.get('-s', os.path.join(img_dir, 'audio'))
-    sndf = os.path.abspath(sndf)
+#    sndf = os.path.abspath(sndf)
     rawsndf = True
     if not os.path.isfile(sndf):
         audio = False
@@ -760,6 +771,8 @@ if __name__ == '__main__':
     do_encode()
     if not keep:
         do_clean()
+    if temp_dir != '':
+        shutil.rmtree(temp_dir)
     if not quiet: print "Done!"
 
 
@@ -795,4 +808,6 @@ CHANGELOG:
                       keeps changing its damn behaviour.
                       Fixed bitrate levels.
 13 Mar 2006 : 0.1.4 : tweaked bitrate levels.
+28 Jun 2007 : 0.1.5 : handles paths with spaces appropriately
+                      (thanks Gabriel).
 """
