@@ -19,7 +19,7 @@ http://www.gnu.org/copyleft/gpl.html for license.
 See my vids at http://amv.reimeika.ca !
 """
 
-version = '0.1.4'
+version = '0.1.5'
 convert = 'convert'
 mplayer = 'mplayer'
 theora_encoder = 'encoder_example'
@@ -439,7 +439,7 @@ mkfifo -m 0600 stream.yuv ; \\
 """ % all_vars
     run(command)
     command = """cd %(source_dir)s ; \\
-%(theora_encoder)s %(theora_opts)s -o %(vidname)s %(wav)s stream.yuv %(std)s
+%(theora_encoder)s %(theora_opts)s -o "%(vidname)s" %(wav)s stream.yuv %(std)s
 """ % all_vars
     run(command)
 
@@ -571,8 +571,14 @@ if __name__ == '__main__':
          print 'Improper image name prefix.'
          raise SystemExit
 
+    temp_dir = ''
     img_dir = opts.get('-d', '.')
     img_dir = os.path.abspath(img_dir)
+    if ' ' in img_dir:
+        temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(img_dir, temp_dir + '/img_dir')
+        img_dir = temp_dir + '/img_dir'
+
     if not os.path.isdir(img_dir):
         print 'The image source directory: '  + img_dir + \
               ' does not exist!'
@@ -722,9 +728,14 @@ if __name__ == '__main__':
             print 'Could not create the work directory ' + \
                   work_dir
             raise SystemExit
+    if ' ' in work_dir:
+        if temp_dir == '':
+            temp_dir = tempfile.mkdtemp('', '.lives-', '/tmp/')
+        os.symlink(work_dir, temp_dir + '/work_dir')
+        work_dir = temp_dir + '/work_dir'
 
     sndf = opts.get('-s', os.path.join(img_dir, 'audio'))
-    sndf = os.path.abspath(sndf)
+#    sndf = os.path.abspath(sndf)
     rawsndf = True
     if not os.path.isfile(sndf):
         audio = False
@@ -751,6 +762,8 @@ if __name__ == '__main__':
     do_encode()
     if not keep:
         do_clean()
+    if temp_dir != '':
+        shutil.rmtree(temp_dir)
     if not quiet: print "Done!"
 
 
@@ -784,4 +797,6 @@ CHANGELOG:
                       keeps changing its damn behaviour.
 02 Apr 2006 : 0.1.4 : small aspect ratio bug fixed.
                       tweaked audio quality settings.
+28 Jun 2007 : 0.1.5 : handles paths with spaces appropriately
+                      (thanks Gabriel).
 """
